@@ -1,9 +1,9 @@
 package Text::Table::Any;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-02-01'; # DATE
+our $DATE = '2021-02-16'; # DATE
 our $DIST = 'Text-Table-Any'; # DIST
-our $VERSION = '0.098'; # VERSION
+our $VERSION = '0.099'; # VERSION
 
 #IFUNBUILT
 # # use 5.010001;
@@ -12,27 +12,30 @@ our $VERSION = '0.098'; # VERSION
 #END IFUNBUILT
 
 our @BACKENDS = qw(
-                      Text::Table::Tiny
-                      Text::Table::TinyBorderStyle
-                      Text::Table::TinyColor
-                      Text::Table::TinyColorWide
-                      Text::Table::TinyWide
-                      Text::Table::Org
-                      Text::Table::CSV
-                      Text::Table::TSV
-                      Text::Table::LTSV
-                      Text::Table::ASV
-                      Text::Table::HTML
-                      Text::Table::HTML::DataTables
-                      Text::Table::Paragraph
+                      Term::TablePrint
                       Text::ANSITable
                       Text::ASCIITable
                       Text::FormatTable
                       Text::MarkdownTable
                       Text::Table
-                      Text::TabularDisplay
+                      Text::Table::ASV
+                      Text::Table::CSV
+                      Text::Table::HTML
+                      Text::Table::HTML::DataTables
+                      Text::Table::LTSV
+                      Text::Table::Manifold
+                      Text::Table::Org
+                      Text::Table::Paragraph
+                      Text::Table::Span
+                      Text::Table::Sprintf
+                      Text::Table::Tiny
+                      Text::Table::TinyBorderStyle
+                      Text::Table::TinyColor
+                      Text::Table::TinyColorWide
+                      Text::Table::TinyWide
+                      Text::Table::TSV
                       Text::Table::XLSX
-                      Term::TablePrint
+                      Text::TabularDisplay
               );
 
 sub _encode {
@@ -72,6 +75,14 @@ sub table {
         require Text::Table::TinyWide;
         return Text::Table::TinyWide::table(
             rows => $rows, header_row => $header_row) . "\n";
+    } elsif ($backend eq 'Text::Table::Span') {
+        require Text::Table::Span;
+        return Text::Table::Span::generate_table(
+            rows => $rows, header_row => $header_row) . "\n";
+    } elsif ($backend eq 'Text::Table::Sprintf') {
+        require Text::Table::Sprintf;
+        return Text::Table::Sprintf::table(
+            rows => $rows, header_row => $header_row) . "\n";
     } elsif ($backend eq 'Text::Table::Org') {
         require Text::Table::Org;
         return Text::Table::Org::table(
@@ -121,6 +132,17 @@ sub table {
             $t->add_row($_) for @$rows;
         }
         return $t->draw;
+    } elsif ($backend eq 'Text::Table::Manifold') {
+        require Text::Table::Manifold;
+        my $t = Text::Table::Manifold->new;
+        if ($header_row) {
+            $t->headers($rows->[0]);
+            $t->data([ @{$rows}[1 .. $#{$rows}] ]);
+        } else {
+            $t->headers([ map {"col$_"} 0..$#{$rows->[0]} ]);
+            $t->data($rows);
+        }
+        return join("\n", @{$t->render(padding => 1)}) . "\n";
     } elsif ($backend eq 'Text::ASCIITable') {
         require Text::ASCIITable;
         my $t = Text::ASCIITable->new();
@@ -196,7 +218,7 @@ Text::Table::Any - Generate text table using one of several backends
 
 =head1 VERSION
 
-This document describes version 0.098 of Text::Table::Any (from Perl distribution Text-Table-Any), released on 2021-02-01.
+This document describes version 0.099 of Text::Table::Any (from Perl distribution Text-Table-Any), released on 2021-02-16.
 
 =head1 SYNOPSIS
 
@@ -326,31 +348,7 @@ Optional. Pick a backend module. Supported backends:
 
 =over
 
-=item * Text::Table::Tiny
-
-=item * Text::Table::TinyBorderStyle
-
-=item * Text::Table::TinyColor
-
-=item * Text::Table::TinyColorWide
-
-=item * Text::Table::TinyWide
-
-=item * Text::Table::Org
-
-=item * Text::Table::CSV
-
-=item * Text::Table::TSV
-
-=item * Text::Table::LTSV
-
-=item * Text::Table::ASV
-
-=item * Text::Table::HTML
-
-=item * Text::Table::HTML::DataTables
-
-=item * Text::Table::Paragraph
+=item * Term::TablePrint
 
 =item * Text::ANSITable
 
@@ -362,11 +360,41 @@ Optional. Pick a backend module. Supported backends:
 
 =item * Text::Table
 
-=item * Text::TabularDisplay
+=item * Text::Table::ASV
+
+=item * Text::Table::CSV
+
+=item * Text::Table::HTML
+
+=item * Text::Table::HTML::DataTables
+
+=item * Text::Table::LTSV
+
+=item * Text::Table::Manifold
+
+=item * Text::Table::Org
+
+=item * Text::Table::Paragraph
+
+=item * Text::Table::Span
+
+=item * Text::Table::Sprintf
+
+=item * Text::Table::Tiny
+
+=item * Text::Table::TinyBorderStyle
+
+=item * Text::Table::TinyColor
+
+=item * Text::Table::TinyColorWide
+
+=item * Text::Table::TinyWide
+
+=item * Text::Table::TSV
 
 =item * Text::Table::XLSX
 
-=item * Term::TablePrint
+=item * Text::TabularDisplay
 
 =back
 
@@ -401,7 +429,7 @@ feature.
 
 =head1 SEE ALSO
 
-L<Bencher::Scenario::TextTableModules>
+L<Acme::CPANModules::TextTable>
 
 =head1 AUTHOR
 
